from os.path import exists, basename
from os import makedirs
from pyspark.sql import SparkSession
from .logger import logger
from .history_db import HistoryDB


server_db = HistoryDB()


def arquee_error(message: str):
    logger.error(message)
    print("ERROR, EXITED")
    server_db.failed_row()
    exit(1)


def create_folder(folder_name: str):
    try:
        if not exists(folder_name):
            makedirs(folder_name)
            logger.info(f"{basename(folder_name)} folder created successfully")
        else:
            logger.info(f"{basename(folder_name)} already exists, skipping creation")
    except Exception as e:
        print(e)
        arquee_error(e)


def get_tables(tables_file: str) -> list[str]:
    try:
        with open(tables_file, "r") as file:
            tables = file.readlines()
            logger.info(f"{tables_file} processed successfully")
            return [table.strip() for table in tables]
    except FileNotFoundError:
        arquee_error(f"File {tables_file} not found")


def create_spark_session() -> SparkSession:
    spark: SparkSession = (
        SparkSession.builder.appName("ETL")
        .master("local[*]")
        .config("spark.executor.memory", "4g")
        .config("spark.sql.parquet.int96RebaseModeInWrite", "CORRECTED")
        .getOrCreate()
    )

    spark.sparkContext.setLogLevel("ERROR")
    return spark
